#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Author: Josef Skladanka <jskladan@redhat.com>

from autotest_lib.client.bin import test, utils
from autotest_lib.client.bin.test_config import config_loader

from decorators import ExceptionCatcher
from util import make_autotest_url

class AutoQATest(test.test, object):
    version = 1 # increment if setup() changes

    def __init__(self, *args, **kwargs):
        super(AutoQATest, self).__init__(*args, **kwargs)
        self.result = None #overall test result ~ "PASSED", "FAILED"...
        self.summary = "" #used as mail-subject
        self.highlights = "" #used as first part of mail-body
        self.outputs = "" #second part of mail_body
        self.mail_to = [] #list of emails to send results to. Mail is always sent to results list

    @ExceptionCatcher("self.initialize_failed")
    def initialize(self, config, **kwargs):
        self.config = config_loader(config, self.tmpdir)
        self.autotest_url = make_autotest_url(self.config)

    @ExceptionCatcher("self.run_once_failed")
    def run_once(self, **kwargs):
        pass

    def initialize_failed(self, exc = None):
        self.result = "CRASHED"
        if exc is not None:
            self.summary = "Initialize failed: %s: %s" % (exc.__class__.__name__, exc)
        else:
            self.summary = "Initialize failed: Exception: Unknown exception"
        try:
            self.postprocess_iteration()
        except:
            pass

    def run_once_failed(self, exc = None):
        self.result = "CRASHED"
        if exc is not None:
            self.summary = "%s: %s" % (exc.__class__.__name__, exc)
        else:
            self.summary = "Exception: Unknown exception"
        try:
            self.postprocess_iteration()
        except:
            pass

    def postprocess_iteration(self):
        if self.result is None:
            self.result = "NEEDS_INSPECTION"
        if self.summary is None or len(self.summary) == 0:
            self.summary = ""
        self.summary = "%s: %s; %s" % (self.__class__.__name__, self.result, self.summary)

        # prepare email
        send_to = []
        result_email = self.config.get('test','result_email')
        if result_email and isinstance(result_email, str):
            send_to = result_email.split(',')
            try:
                for email in self.mail_to:
                    if isinstance(email, str) and len(email) > 0:
                        send_to.append(email)
            except:
                pass

        # print results to the screen
        print '*'*40
        print '* RESULT: %s' % self.result
        print '* SUMMARY: %s' % self.summary
        print '* HIGHLIGHTS: %d lines' % len(self.highlights.splitlines() if self.highlights else '')
        print '* OUTPUTS: %d lines' % len(self.outputs.splitlines() if self.outputs else '')
        print '* EMAIL RECIPIENTS: %s' % ', '.join(send_to)
        print '*'*40

        # send email
        if send_to:
            mail_body = "Stored logs available at <%s>\n\n" % self.autotest_url 
            if self.highlights:
                mail_body += "%s\n" % self.highlights
            mail_body += "-"*70 + "\n"
            mail_body += self.outputs
            utils.send_email(mail_to=send_to,
                    mail_from=self.config.get('test','mail_from'),
                    mail_server=self.config.get('test','smtpserver'),
                    subject=self.summary,
                    body = mail_body)

