#
# Copyright 2009, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Author: Will Woods <wwoods@redhat.com>

import autoqa.util
from autotest_lib.client.bin import utils
from autoqa.test import AutoQATest
from autoqa.decorators import ExceptionCatcher

class repoclosure(AutoQATest):
    version = 1

    def setup(self):
        utils.system('yum -y install yum-utils')

    @ExceptionCatcher("self.run_once_failed")
    def run_once(self, baseurl, parents='', name='', **kwargs):
        if name:
            name = "%s-%s" % (name, autoqa.util.get_basearch())
        else:
            name = baseurl
        # build the repoclosure commandline
        cmd = 'repoclosure --tempcache --newest'
        cmd += ' --repofrompath=target,%s --repoid=target' % baseurl
        count = 1
        for parent in parents:
            name = 'parent-%u' % count
            cmd += ' --repofrompath=%s,%s --repoid=%s' % (name, parent, name)
            count += 1
        # TODO set cachedir etc. to e.g. test.scratchdir?
        out = utils.system_output(cmd, retain_output=True)

        unresolved_count = out.count('unresolved deps:')
        self.write_test_keyval({'unresolved_dep_count':unresolved_count})

        if unresolved_count:
            self.result = "FAILED"
        else:
            self.result = "PASSED"
        self.summary = '%u packages with unresolved deps in %s' % (unresolved_count, name)
        self.highlights = None
        self.outputs = out


